task split_file {
	File D5_trio_raw_vcf
	File D6_trio_raw_vcf
	File family_raw_vcf
	File high_confidence_bed
	String family_name
	String docker
	String cluster_config
	String disk_size
	
	command <<<
		cat ${D5_trio_raw_vcf} | grep '#CHROM' > D5.header
		cat ${D6_trio_raw_vcf} | grep '#CHROM' > D6.header
		cat ${family_raw_vcf} | grep '#CHROM' > family.header

		/opt/ccdg/bedtools-2.27.1/bin/bedtools intersect -a ${D5_trio_raw_vcf} -b ${high_confidence_bed} > D5.in
		/opt/ccdg/bedtools-2.27.1/bin/bedtools intersect -a ${D6_trio_raw_vcf} -b ${high_confidence_bed} > D6.in
		/opt/ccdg/bedtools-2.27.1/bin/bedtools intersect -a ${family_raw_vcf} -b ${high_confidence_bed} > family.in

		/opt/ccdg/bedtools-2.27.1/bin/bedtools intersect -a ${D5_trio_raw_vcf} -b ${high_confidence_bed} -v > D5.out
		/opt/ccdg/bedtools-2.27.1/bin/bedtools intersect -a ${D6_trio_raw_vcf} -b ${high_confidence_bed} -v > D6.out
		/opt/ccdg/bedtools-2.27.1/bin/bedtools intersect -a ${family_raw_vcf} -b ${high_confidence_bed} -v > family.out

		cat D5.header D5.in > ${family_name}.D5.in.txt
		cat D6.header D6.in > ${family_name}.D6.in.txt
		cat family.header family.in > ${family_name}.family.in.txt

		cat D5.header D5.out > ${family_name}.D5.out.txt
		cat D6.header D6.out > ${family_name}.D6.out.txt
		cat family.header family.out > ${family_name}.family.out.txt

		cat ${family_name}.family.in.txt | awk '
		    BEGIN { OFS = "\t" }
		    NF > 2 && FNR > 1 { 
		        for ( i=9; i<=NF; i++ ) { 
		            split($i,a,":") ;$i = a[1];
		        } 
		    } 
		    { print }
		' > ${family_name}.family.in.gt.txt

		cat ${family_name}.family.out.txt | awk '
		    BEGIN { OFS = "\t" }
		    NF > 2 && FNR > 1 { 
		        for ( i=9; i<=NF; i++ ) { 
		            split($i,a,":") ;$i = a[1];
		        } 
		    } 
		    { print }
		' > ${family_name}.family.out.gt.txt

	>>>

	runtime {
		docker:docker
		cluster: cluster_config
		systemDisk: "cloud_ssd 40"
		dataDisk: "cloud_ssd " + disk_size + " /cromwell_root/"
	}
	output {
		File D5_in = "${family_name}.D5.in.txt"
		File D6_in = "${family_name}.D6.in.txt"
		File family_in = "${family_name}.family.in.gt.txt"
		File D5_out = "${family_name}.D5.out.txt"
		File D6_out = "${family_name}.D6.out.txt"
		File family_out = "${family_name}.family.out.gt.txt"
	}
}